#!/bin/bash

function usage() {
    echo "Usage: $0 input.sla output.pdf"
}

if [[ $# -ne 2 ]]; then
    usage
    exit 1
fi

set -ex

export DISPLAY=""
export QT_QPA_PLATFORM="offscreen"

# Scribus >= v1.5.0 is needed.
SCRIBUS_BINARY="scribus"
#SCRIBUS_BINARY="flatpak --user --env="QT_QPA_PLATFORM=offscreen" run net.scribus.Scribus"

TMP_FILE=$(mktemp pdfx3-XXXXXX.pdf)
trap "rm -f -- '$TMP_FILE'" EXIT

infile=$(realpath -m "$1")
outfile=$(realpath -m "$2")

cd "$(dirname "$0")"

# Create pre-press PDF 1.4 File (contains transparencies).
$SCRIBUS_BINARY "$infile" -ns -g -py export_to_pdf.py \
    -version 14 -binding 0 -compress 1 -compressmtd 0 -quality 0 \
    -outdst 1 -profilei 1 \
    -cropMarks 1 -bleedMarks 1 -useDocBleeds 1 \
    -info 'Igalia' -file "${TMP_FILE}"

# Convert to PDF/X-3.
# Previously, we were doing an intermediate step to preserve as
# vectors the objects without transparencies but it doesn't seem to
# work:
# https://bugs.ghostscript.com/show_bug.cgi?id=703180
gs -dQUIET -dBATCH -dNOPAUSE \
   -dPDFX -sProcessColorModel=DeviceCMYK -sColorConversionStrategy=CMYK \
   -sDEVICE=pdfwrite \
   -sOutputFile="$outfile" -P  PDFX_def.ps "${TMP_FILE}"
